@@ -280,6 +280,17 @@ class Cache:
         if self.allScoreSSE and self.MultiObjectiveSSE is False:
             self.numGoals = 1
 
+        if self.allScoreNorm:
+            #use the first 4 indexes to also keep the SSE
+            self.meta_slice = slice(0, 4, 1)
+        elif self.allScoreSSE:
+            if self.MultiObjectiveSSE:
+                #use the first 3 indexes
+                self.meta_slice = slice(0,3,1)
+            else:
+                #only used index = 3 
+                self.meta_slice = slice(3,4,1)
+
         self.headers.extend(self.score_headers)                      
         
         self.meta_headers = ['Product Root Score', 'Min Score', 'Mean Score', 'SSE', 'RMSE']
@@ -328,19 +339,6 @@ class Cache:
         #SSE are negative so they sort correctly with better scores being less negative
         self.target['bestHumanScores'][4] = self.badScore;  
 
-        #setup sensitivities
-        parms = []
-        sensitivityOk = 1
-        for parameter in self.parameters:
-            if parameter.count:
-                sens_parms, sensitivityOk = parameter.setupTarget()
-                parms.extend(sens_parms)
-
-        if sensitivityOk:
-            self.target['sensitivities'] = parms
-        else:
-            self.target['sensitivities'] = []
-
     def setupExperiment(self, experiment, sim=None, dataFromSim=0):
         temp = {}
 
