@@ -259,13 +259,13 @@ def set_simulation(individual, simulation, settings, cache, experiment):
 def getBoundOffset(unit):
     if unit.unit_type == b'CSTR':
         NBOUND = unit.nbound
-
-        if not NBOUND:
-            "For a CSTR with NBOUND not set the default is all 0"
-            NBOUND = [0.0] * unit.ncomp
     else:
         NBOUND = unit.discretization.nbound
 
+    if not len(NBOUND):
+        "If NBOUND is empty it is all zero"
+        NBOUND = [0.0] * unit.ncomp
+
     boundOffset = numpy.cumsum(numpy.concatenate([[0,], NBOUND]))
     return boundOffset
 
@@ -752,9 +752,9 @@ def writeProgress(cache, generation, population, halloffame, meta_halloffame, gr
                 hf["output"].resize((hf["output"].shape[0] + len(result_data['output'])), axis = 0)
                 hf["output"][-len(result_data['output']):] = result_data['output']
 
-                data = result_data['output_meta']
-                length = len(data)
-                length_item = len(data[0])
+                #data = numpy.array(result_data['output_meta'])
+                #length = len(data)
+                #length_item = len(data[0])
                 hf["output_meta"].resize((hf["output_meta"].shape[0] + len(result_data['output_meta'])), axis = 0)
                 hf["output_meta"][-len(result_data['output_meta']):] = result_data['output_meta']
 
